@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: math-functions
 version: 0.1.5.2
-id: math-functions-0.1.5.2-cca3e664aeca2116145d4ae702f767c6
-key: mathf_A9DHuwO2BZXLLz4oXGAjY0
+id: math-functions-0.1.5.2-7a985a285f902888d75b2085436cd768
+key: mathf_3LEsvkri95Y0iU7IlgKIu5
 license: BSD3
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
 homepage: https://github.com/bos/math-functions
@@ -24,13 +24,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/math-functions-0.1.5.2
-hs-libraries: HSmath-functions-0.1.5.2-A9DHuwO2BZXLLz4oXGAjY0
+hs-libraries: HSmath-functions-0.1.5.2-3LEsvkri95Y0iU7IlgKIu5
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     erf-2.0.0.0-aab48415b057e47fae23d9f8b194cc70
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    vector-th-unbox-0.2.1.4-1139d5b6f0cb29dac6aff26bf8525b7e
+    vector-th-unbox-0.2.1.5-8f7270dc4460c13d7b9488d6341118f7
 haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
 haddock-html: /usr/share/doc/haskell-math-functions/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
